@@ -43,12 +43,11 @@ sub output {
             if ($file) {
                 $file->output($program_name, $metric_name, $metric);
             }
-
-            if ($mackerel) {
-                $mackerel->output($program_name, $metric_name, $metric);
-            }
         }
     }
+    if ($mackerel) {
+        $mackerel->bulk_output($ret_pidstats);
+    }
 }
 
 1;
